Crate scalar_axum

Crate scalar_axum 

Modules

expire_map

Macros

generate_routes

Structs

AuthenticatedConnection
PublishParams
ValidateQueryParams
ValidationFailiure

Functions

delete_doc
Endpoint that deletes a docs.
delete_draft
Endpoint that deletes a draft.
get_all_docs
Endpoint that gets all documents of a certain type.
get_doc_by_id
Endpoint that gets a document by id.
get_schema
me
publish_doc
Endpoint that publishes the document, if it’s valid.
signin
Endpoint that signs a user in with a username and password.
unpublish_doc
Endpoint that unpublishes the document, and puts the current version as a draft.
update_draft
Endpoint that updates a draft.
validate
Endpoint to validate a document.