Modules
Macros
Structs
Functions
- delete_
doc - Endpoint that deletes a docs.
- delete_
draft - Endpoint that deletes a draft.
- get_
all_ docs - Endpoint that gets all documents of a certain type.
- get_
doc_ by_ id - Endpoint that gets a document by id.
- get_
schema - me
- publish_
doc - Endpoint that publishes the document, if it’s valid.
- signin
- Endpoint that signs a user in with a username and password.
- unpublish_
doc - Endpoint that unpublishes the document, and puts the current version as a draft.
- update_
draft - Endpoint that updates a draft.
- validate
- Endpoint to validate a document.